@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-07-27 05:34:42 -0600 (Mon, 27 Jul 2009) $
-#   $Revision: 4196 $
+#   $Date: 2009-08-15 07:29:25 -0600 (Sat, 15 Aug 2009) $
+#   $Revision: 4336 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -107,7 +107,7 @@ cat   x14680064   x14680064 >  x29360128
 echo "---------------"
 echo " prep disk..."
 echo "---------------"
-if ! $EXEC/prep_disk; then
+if ! $EXEC/src/apps/util/prep_disk; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -122,9 +122,9 @@ sleep 2
 echo "---------------------"
 echo " compress before..."
 echo "---------------------"
-if ! $EXEC/compress_sparse /tmp/objectify_test/compressed-before; then
+if ! $EXEC/src/apps/util/compress_archive /tmp/objectify_test/compressed-before; then
    echo ""
-   echo "compress_sparse failed"
+   echo "compress_archive failed"
    echo ""
    exit 1
 fi
@@ -134,7 +134,7 @@ sleep 2
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file x1*; then
+if ! $EXEC/src/apps/file/import_file x1*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -143,7 +143,7 @@ fi
 
 sleep 1
 
-if ! $EXEC/import_file x2*; then
+if ! $EXEC/src/apps/file/import_file x2*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -152,7 +152,7 @@ fi
 
 sleep 1
 
-if ! $EXEC/import_file x3*; then
+if ! $EXEC/src/apps/file/import_file x3*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -161,7 +161,7 @@ fi
 
 sleep 1
 
-if ! $EXEC/import_file x4*; then
+if ! $EXEC/src/apps/file/import_file x4*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -170,7 +170,7 @@ fi
 
 sleep 1
 
-if ! $EXEC/import_file x5*; then
+if ! $EXEC/src/apps/file/import_file x5*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -179,7 +179,7 @@ fi
 
 sleep 1
 
-if ! $EXEC/import_file x7*; then
+if ! $EXEC/src/apps/file/import_file x7*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -188,7 +188,7 @@ fi
 
 sleep 1
 
-if ! $EXEC/import_file x8*; then
+if ! $EXEC/src/apps/file/import_file x8*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -197,7 +197,7 @@ fi
 
 sleep 1
 
-if ! $EXEC/import_file x9*; then
+if ! $EXEC/src/apps/file/import_file x9*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -210,9 +210,9 @@ sleep 2
 echo "---------------------"
 echo " compress after..."
 echo "---------------------"
-if ! $EXEC/compress_sparse /tmp/objectify_test/compressed-after; then
+if ! $EXEC/src/apps/util/compress_archive /tmp/objectify_test/compressed-after; then
    echo ""
-   echo "compress_sparse failed"
+   echo "compress_archive failed"
    echo ""
    exit 1
 fi
@@ -223,7 +223,7 @@ sleep 2
 echo "---------------------"
 echo " diff compressed..."
 echo "---------------------"
-if ! $EXEC/diff_compressed /tmp/objectify_test/compressed-before /tmp/objectify_test/compressed-after /tmp/objectify_test/diff-before-after > /tmp/objectify_test/diff-before-after.txt; then
+if ! $EXEC/src/apps/util/diff_compressed /tmp/objectify_test/compressed-before /tmp/objectify_test/compressed-after /tmp/objectify_test/diff-before-after > /tmp/objectify_test/diff-before-after.txt; then
    echo ""
    echo "diff_compressed failed"
    echo ""
@@ -236,7 +236,7 @@ sleep 2
 echo "---------------------"
 echo " combine backups..."
 echo "---------------------"
-if ! $EXEC/combine_backup_files /tmp/objectify_test/*.dif /tmp/objectify_test/combined-before-after; then
+if ! $EXEC/src/apps/util/combine_backup_files /tmp/objectify_test/*.dif /tmp/objectify_test/combined-before-after; then
    echo ""
    echo "combine_backup_files failed"
    echo ""
@@ -262,7 +262,7 @@ sleep 2
 echo "---------------------"
 echo " patch compressed..."
 echo "---------------------"
-if ! $EXEC/patch_compressed /tmp/objectify_test/compressed-before /tmp/objectify_test/combined-before-after /tmp/objectify_test/patched-after > /tmp/objectify_test/patched-after.txt; then
+if ! $EXEC/src/apps/util/patch_compressed /tmp/objectify_test/compressed-before /tmp/objectify_test/combined-before-after /tmp/objectify_test/patched-after > /tmp/objectify_test/patched-after.txt; then
    echo ""
    echo "patch_compressed failed"
    echo ""
@@ -290,7 +290,7 @@ sleep 2
 echo "--------------------------"
 echo " prep disk for restore..."
 echo "--------------------------"
-if ! $EXEC/prep_disk --no-private; then
+if ! $EXEC/src/apps/util/prep_disk --no-private; then
    echo ""
    echo "prep_disk --no-private failed"
    echo ""
@@ -301,16 +301,16 @@ fi
 echo "---------------------"
 echo " expand..."
 echo "---------------------"
-if ! $EXEC/expand_sparse /tmp/objectify_test/patched-after; then
+if ! $EXEC/src/apps/util/restore_archive /tmp/objectify_test/patched-after; then
    echo ""
-   echo "expand_sparse failed"
+   echo "restore_archive failed"
    echo ""
    exit 1
 fi
 
 
 
-if ! $EXEC/export_file "*"; then
+if ! $EXEC/src/apps/file/export_file "*"; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -323,7 +323,7 @@ for file in ../*.[ch]; do diff -s $file .; done
 echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
-if ! $EXEC/verify_file --remove-no-shred *; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred failed"
    echo ""
@@ -336,7 +336,7 @@ echo "---------------------------"
 echo " prep a second archive..."
 echo "---------------------------"
 
-if ! $EXEC/prep_disk --no-private /tmp/objectify_test/private2.obj; then
+if ! $EXEC/src/apps/util/prep_disk --no-private /tmp/objectify_test/private2.obj; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -349,7 +349,7 @@ sleep 2
 echo "---------------------"
 echo " sync archive..."
 echo "---------------------"
-if ! $EXEC/sync_archive /tmp/objectify_test/private2.obj; then
+if ! $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private2.obj; then
    echo ""
    echo "sync_archive failed"
    echo ""
@@ -365,9 +365,9 @@ echo "------------------------------"
 
 export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private2.obj
 
-if ! $EXEC/compress_sparse /tmp/objectify_test/compressed-second; then
+if ! $EXEC/src/apps/util/compress_archive /tmp/objectify_test/compressed-second; then
    echo ""
-   echo "compress_sparse failed"
+   echo "compress_archive failed"
    echo ""
    exit 1
 fi
@@ -378,7 +378,7 @@ sleep 2
 echo "-----------------------------------------------------"
 echo " verify first and second compressed are the same..."
 echo "-----------------------------------------------------"
-if ! $EXEC/diff_compressed /tmp/objectify_test/compressed-after /tmp/objectify_test/compressed-second; then
+if ! $EXEC/src/apps/util/diff_compressed /tmp/objectify_test/compressed-after /tmp/objectify_test/compressed-second; then
    echo ""
    echo "first and second compressed files differ"
    echo ""
@@ -394,7 +394,7 @@ echo "---------------------------"
 echo " prep a third archive..."
 echo "---------------------------"
 
-if ! $EXEC/prep_disk --no-private /tmp/objectify_test/private3.obj; then
+if ! $EXEC/src/apps/util/prep_disk --no-private /tmp/objectify_test/private3.obj; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -407,7 +407,7 @@ sleep 2
 echo "---------------------"
 echo " sync archive..."
 echo "---------------------"
-if ! $EXEC/sync_archive /tmp/objectify_test/private2.obj /tmp/objectify_test/private3.obj; then
+if ! $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private2.obj /tmp/objectify_test/private3.obj; then
    echo ""
    echo "sync_archive failed"
    echo ""
@@ -423,9 +423,9 @@ echo "------------------------------"
 
 export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private3.obj
 
-if ! $EXEC/compress_sparse /tmp/objectify_test/compressed-third; then
+if ! $EXEC/src/apps/util/compress_archive /tmp/objectify_test/compressed-third; then
    echo ""
-   echo "compress_sparse failed"
+   echo "compress_archive failed"
    echo ""
    exit 1
 fi
@@ -436,7 +436,7 @@ sleep 2
 echo "-----------------------------------------------------"
 echo " verify first and third compressed are the same..."
 echo "-----------------------------------------------------"
-if ! $EXEC/diff_compressed /tmp/objectify_test/compressed-after /tmp/objectify_test/compressed-third; then
+if ! $EXEC/src/apps/util/diff_compressed /tmp/objectify_test/compressed-after /tmp/objectify_test/compressed-third; then
    echo ""
    echo "first and third compressed files differ"
    echo ""
@@ -452,7 +452,7 @@ echo "---------------------------"
 echo " prep a fourth archive..."
 echo "---------------------------"
 
-if ! $EXEC/prep_disk /tmp/objectify_test/private4.obj; then
+if ! $EXEC/src/apps/util/prep_disk /tmp/objectify_test/private4.obj; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -468,9 +468,9 @@ echo "-----------------------------------"
 
 export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private4.obj
 
-if $EXEC/expand_sparse /tmp/objectify_test/patched-after; then
+if $EXEC/src/apps/util/restore_archive /tmp/objectify_test/patched-after; then
    echo ""
-   echo "expand_sparse into non-empty archive succeeded"
+   echo "restore_archive into non-empty archive succeeded"
    echo ""
    exit 1
 fi
@@ -481,7 +481,7 @@ sleep 2
 echo "------------------------------------------"
 echo " sync archive into non-empty archive..."
 echo "------------------------------------------"
-if $EXEC/sync_archive /tmp/objectify_test/private3.obj /tmp/objectify_test/private4.obj; then
+if $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private3.obj /tmp/objectify_test/private4.obj; then
    echo ""
    echo "sync_archive into non-empty archive succeeded"
    echo ""
@@ -494,7 +494,7 @@ sleep 2
 echo "------------------------------------------"
 echo " sync archive with duplicate path..."
 echo "------------------------------------------"
-if $EXEC/sync_archive /tmp/objectify_test/private4.obj; then
+if $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private4.obj; then
    echo ""
    echo "sync_archive with duplicate path succeeded"
    echo ""
@@ -506,7 +506,7 @@ sleep 2
 echo "------------------------------------------"
 echo " sync archive with duplicate paths..."
 echo "------------------------------------------"
-if $EXEC/sync_archive /tmp/objectify_test/private3.obj /tmp/objectify_test/private3.obj; then
+if $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private3.obj /tmp/objectify_test/private3.obj; then
    echo ""
    echo "sync_archive with duplicate paths succeeded"
    echo ""
