@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
-#   $Revision: 4184 $
+#   $Date: 2009-08-13 06:05:50 -0600 (Thu, 13 Aug 2009) $
+#   $Revision: 4325 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -104,7 +104,7 @@ echo "------------------"
 
 echo $OBJECTIFY_PRIVATE_PATH
 
-if ! $EXEC/prep_disk; then
+if ! $EXEC/src/apps/util/prep_disk; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -117,28 +117,28 @@ echo "------------------------------------------------------------------"
 echo " test that programs fail when there are no files in the system..."
 echo "------------------------------------------------------------------"
 
-if $EXEC/import_file test1.txt; then
+if $EXEC/src/apps/file/import_file test1.txt; then
    echo ""
    echo "import non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/verify_file test1.txt; then
+if $EXEC/src/apps/file/verify_file test1.txt; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/export_file test1.txt; then
+if $EXEC/src/apps/file/export_file test1.txt; then
    echo ""
    echo "export non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/list_files test1.txt; then
+if $EXEC/src/apps/file/list_files test1.txt; then
    echo ""
    echo "list non-existant file succeeded"
    echo ""
@@ -152,7 +152,7 @@ echo "-------------------------"
 
 echo "This is test #1" >> test1.txt
 
-if ! $EXEC/import_file test1.txt > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/import_file test1.txt > /tmp/test1.out; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -166,7 +166,7 @@ if ! grep -q "files created:   1" /tmp/test1.out; then
    exit 1
 fi
 
-if ! $EXEC/list_files --md5 test1.txt > test1.md5; then
+if ! $EXEC/src/apps/file/list_files --md5 test1.txt > test1.md5; then
    echo ""
    echo "list_files --md5 failed"
    echo ""
@@ -180,7 +180,7 @@ if ! md5sum -c test1.md5; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha1 test1.txt > test1.sha1; then
+if ! $EXEC/src/apps/file/list_files --sha1 test1.txt > test1.sha1; then
    echo ""
    echo "list_files --sha1 failed"
    echo ""
@@ -194,7 +194,7 @@ if ! sha1sum -c test1.sha1; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha256 test1.txt > test1.sha256; then
+if ! $EXEC/src/apps/file/list_files --sha256 test1.txt > test1.sha256; then
    echo ""
    echo "list_files --sha256 failed"
    echo ""
@@ -208,7 +208,7 @@ if ! sha256sum -c test1.sha256; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha512 test1.txt > test1.sha512; then
+if ! $EXEC/src/apps/file/list_files --sha512 test1.txt > test1.sha512; then
    echo ""
    echo "list_files --sha512 failed"
    echo ""
@@ -222,28 +222,28 @@ if ! sha512sum -c test1.sha512; then
    exit 1
 fi
 
-if ! $EXEC/verify_file test1.txt; then
+if ! $EXEC/src/apps/file/verify_file test1.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if $EXEC/verify_file test1.txt; then
+if $EXEC/src/apps/file/verify_file test1.txt; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/export_file test1.txt; then
+if ! $EXEC/src/apps/file/export_file test1.txt; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -291,7 +291,7 @@ if ! touch test1.txt; then
    exit 1
 fi
 
-if ! $EXEC/import_file test1.txt > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/import_file test1.txt > /tmp/test1.out; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -305,28 +305,28 @@ if ! grep -q "existing files:  1" /tmp/test1.out; then
    exit 1
 fi
 
-if $EXEC/verify_file test1.txt; then
+if $EXEC/src/apps/file/verify_file test1.txt; then
    echo ""
    echo "verify file with different time stamp succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/verify_file --remove-no-shred test1.txt; then
+if $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
    echo ""
    echo "verify file --remove with different time stamp succeeded"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --ignore-time test1.txt; then
+if ! $EXEC/src/apps/file/verify_file --ignore-time test1.txt; then
    echo ""
    echo "verify file with --ignore-time failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --ignore-time --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/verify_file --ignore-time --remove-no-shred test1.txt; then
    echo ""
    echo "verify file --remove --ignore-time failed"
    echo ""
@@ -339,28 +339,28 @@ echo "-----------------------------------------------------------"
 echo " test that programs fail when file isn't in the system..."
 echo "-----------------------------------------------------------"
 
-if $EXEC/import_file test2.txt; then
+if $EXEC/src/apps/file/import_file test2.txt; then
    echo ""
    echo "import non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/verify_file test2.txt; then
+if $EXEC/src/apps/file/verify_file test2.txt; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/export_file test2.txt; then
+if $EXEC/src/apps/file/export_file test2.txt; then
    echo ""
    echo "export non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/list_files test2.txt; then
+if $EXEC/src/apps/file/list_files test2.txt; then
    echo ""
    echo "list non-existant file succeeded"
    echo ""
@@ -374,7 +374,7 @@ echo "---------------------------------------------------"
 
 echo "This is test #1" >> test1diffname.txt
 
-if $EXEC/import_file test1diffname.txt > /tmp/test1.out; then
+if $EXEC/src/apps/file/import_file test1diffname.txt > /tmp/test1.out; then
    echo ""
    echo "import duplicate file succeeded"
    echo ""
@@ -397,7 +397,7 @@ mkdir subdir
 
 mv -i test1diffname.txt subdir
 
-if ! $EXEC/import_file -r subdir > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/import_file -r subdir > /tmp/test1.out; then
    echo ""
    echo "import_file subdir failed"
    echo ""
@@ -411,35 +411,35 @@ if ! grep -q "new paths:       1" /tmp/test1.out; then
    exit 1
 fi
 
-if ! $EXEC/verify_file -r subdir; then
+if ! $EXEC/src/apps/file/verify_file -r subdir; then
    echo ""
    echo "verify_file subdir failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred -r subdir; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred -r subdir; then
    echo ""
    echo "verify_file --remove subdir failed"
    echo ""
    exit 1
 fi
 
-if $EXEC/verify_file subdir; then
+if $EXEC/src/apps/file/verify_file subdir; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/export_file subdir/*; then
+if ! $EXEC/src/apps/file/export_file subdir/*; then
    echo ""
    echo "export_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/import_file subdir/* > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/import_file subdir/* > /tmp/test1.out; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -460,21 +460,21 @@ echo "-------------------------------------------------"
 
 echo "Test #1, has been changed" >> test1.txt
 
-if $EXEC/verify_file test1.txt; then
+if $EXEC/src/apps/file/verify_file test1.txt; then
    echo ""
    echo "verify_file revised file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/verify_file --remove-no-shred test1.txt; then
+if $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
    echo ""
    echo "verify_file --remove revised file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/import_file test1.txt > /tmp/test1r.out; then
+if $EXEC/src/apps/file/import_file test1.txt > /tmp/test1r.out; then
    echo ""
    echo "import_file revised file without --add-revision succeeded"
    echo ""
@@ -496,7 +496,7 @@ echo "---------------------------"
 mkdir 20081221-909
 echo "Testing import data" >> 20081221-909/test2.txt
 
-if ! $EXEC/disc_list 20081221-909 <<EOF ; then
+if ! $EXEC/src/apps/file/disc_list 20081221-909 <<EOF ; then
 20081221-909
 EOF
    echo ""
@@ -505,7 +505,7 @@ EOF
    exit 1
 fi
 
-if $EXEC/export_file test2.txt; then
+if $EXEC/src/apps/file/export_file test2.txt; then
    echo ""
    echo "export file with no data succeeded"
    echo ""
@@ -515,7 +515,7 @@ fi
 mv -i 20081221-909/test2.txt .
 rmdir 20081221-909
 
-if ! $EXEC/list_files --md5 test2.txt > test2.md5; then
+if ! $EXEC/src/apps/file/list_files --md5 test2.txt > test2.md5; then
    echo ""
    echo "list_files --md5 failed"
    echo ""
@@ -529,7 +529,7 @@ if ! md5sum -c test2.md5; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha1 test2.txt > test2.sha1; then
+if ! $EXEC/src/apps/file/list_files --sha1 test2.txt > test2.sha1; then
    echo ""
    echo "list_files --sha1 failed"
    echo ""
@@ -543,7 +543,7 @@ if ! sha1sum -c test2.sha1; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha256 test2.txt > test2.sha256; then
+if ! $EXEC/src/apps/file/list_files --sha256 test2.txt > test2.sha256; then
    echo ""
    echo "list_files --sha256 failed"
    echo ""
@@ -557,7 +557,7 @@ if ! sha256sum -c test2.sha256; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha512 test2.txt > test2.sha512; then
+if ! $EXEC/src/apps/file/list_files --sha512 test2.txt > test2.sha512; then
    echo ""
    echo "list_files --sha512 failed"
    echo ""
@@ -572,14 +572,14 @@ if ! sha512sum -c test2.sha512; then
 fi
 
 
-if ! $EXEC/verify_file test2.txt; then
+if ! $EXEC/src/apps/file/verify_file test2.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if $EXEC/verify_file --remove-no-shred test2.txt; then
+if $EXEC/src/apps/file/verify_file --remove-no-shred test2.txt; then
    echo ""
    echo "verify_file --remove no data succeeded"
    echo ""
@@ -587,7 +587,7 @@ if $EXEC/verify_file --remove-no-shred test2.txt; then
 fi
 
 
-if ! $EXEC/import_file test2.txt > /tmp/test2i.out; then
+if ! $EXEC/src/apps/file/import_file test2.txt > /tmp/test2i.out; then
    echo ""
    echo "import_file data failed"
    echo ""
@@ -602,14 +602,14 @@ if ! grep -q "imported data:   1" /tmp/test2i.out; then
 fi
 
 
-if ! $EXEC/verify_file test2.txt; then
+if ! $EXEC/src/apps/file/verify_file test2.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred test2.txt; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred test2.txt; then
    echo ""
    echo "verify_file --remove failed"
    echo ""
@@ -617,7 +617,7 @@ if ! $EXEC/verify_file --remove-no-shred test2.txt; then
 fi
 
 
-if ! $EXEC/export_file test2.txt; then
+if ! $EXEC/src/apps/file/export_file test2.txt; then
    echo ""
    echo "export file failed"
    echo ""
@@ -652,7 +652,7 @@ if ! sha512sum -c test2.sha512; then
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-min-shred test2.txt; then
+if ! $EXEC/src/apps/file/verify_file --remove-min-shred test2.txt; then
    echo ""
    echo "verify_file --remove-min-shred failed"
    echo ""
@@ -667,7 +667,7 @@ echo "--------------------------------------"
 
 echo "This is test #1" >> test2.txt
 
-if $EXEC/import_file test2.txt > /tmp/test2e.out; then
+if $EXEC/src/apps/file/import_file test2.txt > /tmp/test2e.out; then
    echo ""
    echo "import_file path and file exist succeeded"
    echo ""
@@ -682,7 +682,7 @@ if ! grep -q "duplicate files: 1" /tmp/test2e.out; then
 fi
 
 
-if $EXEC/import_file -r test2.txt > /tmp/test2e.out; then
+if $EXEC/src/apps/file/import_file -r test2.txt > /tmp/test2e.out; then
    echo ""
    echo "import_file -r path and file exist succeeded"
    echo ""
@@ -703,7 +703,7 @@ echo "--------------------------------------"
 
 echo "This is test #8" >> test8.txt
 
-if ! $EXEC/import_file test8.txt > /tmp/test8.out; then
+if ! $EXEC/src/apps/file/import_file test8.txt > /tmp/test8.out; then
    echo ""
    echo "import_file test8.txt failed"
    echo ""
@@ -714,7 +714,7 @@ sleep 1
 
 cp test8.txt Test8.txt
 
-if $EXEC/import_file Test8.txt > /tmp/test8.out; then
+if $EXEC/src/apps/file/import_file Test8.txt > /tmp/test8.out; then
    echo ""
    echo "import_file Test8.txt succeeded"
    echo ""
@@ -729,7 +729,7 @@ if ! grep -q "duplicate files: 1" /tmp/test8.out; then
 fi
 
 
-if ! $EXEC/import_file -r Test8.txt > /tmp/test8.out; then
+if ! $EXEC/src/apps/file/import_file -r Test8.txt > /tmp/test8.out; then
    echo ""
    echo "import_file -r Test8.txt failed"
    echo ""
@@ -743,7 +743,7 @@ if ! grep -q "new paths:       1" /tmp/test8.out; then
    exit 1
 fi
 
-if ! $EXEC/list_files --md5 ?est8.txt > test8.md5; then
+if ! $EXEC/src/apps/file/list_files --md5 ?est8.txt > test8.md5; then
    echo ""
    echo "list_files --md5 failed"
    echo ""
@@ -757,7 +757,7 @@ if ! md5sum -c test8.md5; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha1 ?est8.txt > test8.sha1; then
+if ! $EXEC/src/apps/file/list_files --sha1 ?est8.txt > test8.sha1; then
    echo ""
    echo "list_files --sha1 failed"
    echo ""
@@ -771,7 +771,7 @@ if ! sha1sum -c test8.sha1; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha256 ?est8.txt > test8.sha256; then
+if ! $EXEC/src/apps/file/list_files --sha256 ?est8.txt > test8.sha256; then
    echo ""
    echo "list_files --sha256 failed"
    echo ""
@@ -785,7 +785,7 @@ if ! sha256sum -c test8.sha256; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha512 ?est8.txt > test8.sha512; then
+if ! $EXEC/src/apps/file/list_files --sha512 ?est8.txt > test8.sha512; then
    echo ""
    echo "list_files --sha512 failed"
    echo ""
@@ -799,21 +799,21 @@ if ! sha512sum -c test8.sha512; then
    exit 1
 fi
 
-if ! $EXEC/verify_file ?est8.txt; then
+if ! $EXEC/src/apps/file/verify_file ?est8.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred ?est8.txt; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred ?est8.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/export_file ?est8.txt; then
+if ! $EXEC/src/apps/file/export_file ?est8.txt; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -856,7 +856,7 @@ echo "--------------------------------------"
 echo "This is test #9" >> test9.txt
 echo "This is Test #9" >> Test9.txt
 
-if ! $EXEC/import_file test9.txt Test9.txt > /tmp/test9.out; then
+if ! $EXEC/src/apps/file/import_file test9.txt Test9.txt > /tmp/test9.out; then
    echo ""
    echo "import_file test9.txt failed"
    echo ""
@@ -871,7 +871,7 @@ if ! grep -q "files created:   2" /tmp/test9.out; then
 fi
 
 
-if ! $EXEC/list_files --md5 ?est9.txt > test9.md5; then
+if ! $EXEC/src/apps/file/list_files --md5 ?est9.txt > test9.md5; then
    echo ""
    echo "list_files --md5 failed"
    echo ""
@@ -885,7 +885,7 @@ if ! md5sum -c test9.md5; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha1 ?est9.txt > test9.sha1; then
+if ! $EXEC/src/apps/file/list_files --sha1 ?est9.txt > test9.sha1; then
    echo ""
    echo "list_files --sha1 failed"
    echo ""
@@ -899,7 +899,7 @@ if ! sha1sum -c test9.sha1; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha256 ?est9.txt > test9.sha256; then
+if ! $EXEC/src/apps/file/list_files --sha256 ?est9.txt > test9.sha256; then
    echo ""
    echo "list_files --sha256 failed"
    echo ""
@@ -913,7 +913,7 @@ if ! sha256sum -c test9.sha256; then
    exit 1
 fi
 
-if ! $EXEC/list_files --sha512 ?est9.txt > test9.sha512; then
+if ! $EXEC/src/apps/file/list_files --sha512 ?est9.txt > test9.sha512; then
    echo ""
    echo "list_files --sha512 failed"
    echo ""
@@ -927,21 +927,21 @@ if ! sha512sum -c test9.sha512; then
    exit 1
 fi
 
-if ! $EXEC/verify_file ?est9.txt; then
+if ! $EXEC/src/apps/file/verify_file ?est9.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred ?est9.txt; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred ?est9.txt; then
    echo ""
    echo "verify_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/export_file ?est9.txt; then
+if ! $EXEC/src/apps/file/export_file ?est9.txt; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -983,7 +983,7 @@ echo "--------------------------------------------------"
 
 echo "This is test #1" > test2.txt
 
-if $EXEC/import_file --add-revision test2.txt > /tmp/test8r.out; then
+if $EXEC/src/apps/file/import_file --add-revision test2.txt > /tmp/test8r.out; then
    echo ""
    echo "import_file --add-revision new file succeeded"
    echo ""
@@ -1000,7 +1000,7 @@ fi
 
 echo "This is test #1" > test3.txt
 
-if $EXEC/import_file --add-revision test2.txt > /tmp/test8r.out; then
+if $EXEC/src/apps/file/import_file --add-revision test2.txt > /tmp/test8r.out; then
    echo ""
    echo "import_file --add-revision new file succeeded"
    echo ""
@@ -1021,7 +1021,7 @@ echo "-------------------------------------------------"
 
 echo "This is test #3" > test3.txt
 
-if $EXEC/import_file --add-revision test3.txt > /tmp/test3r.out; then
+if $EXEC/src/apps/file/import_file --add-revision test3.txt > /tmp/test3r.out; then
    echo ""
    echo "import_file --add-revision new file succeeded"
    echo ""
@@ -1040,7 +1040,7 @@ echo "---------------------------"
 echo " Case 12: revised file..."
 echo "---------------------------"
 
-if ! $EXEC/import_file --add-revision test1.txt > /tmp/test1r.out; then
+if ! $EXEC/src/apps/file/import_file --add-revision test1.txt > /tmp/test1r.out; then
    echo ""
    echo "import_file --add-revision failed"
    echo ""
@@ -1054,35 +1054,35 @@ if ! grep -q "new revisions:   1" /tmp/test1r.out; then
    exit 1
 fi
 
-if ! $EXEC/verify_file test1.txt; then
+if ! $EXEC/src/apps/file/verify_file test1.txt; then
    echo ""
    echo "verify_file revised file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
    echo ""
    echo "verify_file --remove revised file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/export_file test1.txt; then
+if ! $EXEC/src/apps/file/export_file test1.txt; then
    echo ""
    echo "export_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file test1.txt; then
+if ! $EXEC/src/apps/file/verify_file test1.txt; then
    echo ""
    echo "verify_file revised file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
    echo ""
    echo "verify_file --remove revised file failed"
    echo ""
