@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
-#   $Revision: 4184 $
+#   $Date: 2009-08-15 07:40:34 -0600 (Sat, 15 Aug 2009) $
+#   $Revision: 4337 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -68,13 +68,13 @@ if ! rm -fr /tmp/test; then
 fi
 
 mkdir /tmp/test
-cp -p *.[ch] /tmp/test
+cp -p src/*/*/*.[ch] /tmp/test
 cd /tmp/test
 
 echo "---------------"
 echo " prep disk..."
 echo "---------------"
-if ! $EXEC/prep_disk; then
+if ! $EXEC/src/apps/util/prep_disk; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -86,7 +86,7 @@ sleep 2
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file *.[ch] > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/import_file *.[ch] > /tmp/test1.out; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -101,7 +101,7 @@ echo "-----------------"
 mkdir test
 cd test
 
-if ! $EXEC/export_file "*"; then
+if ! $EXEC/src/apps/file/export_file "*"; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -115,7 +115,7 @@ echo "-------------------"
 echo " md5 checksums..."
 echo "-------------------"
 
-if ! $EXEC/list_files --md5  | tee ../a.md5; then
+if ! $EXEC/src/apps/file/list_files --md5  | tee ../a.md5; then
    echo ""
    echo "list_files --md5 failed"
    echo ""
@@ -134,7 +134,7 @@ echo "-------------------"
 echo " sha1 checksums..."
 echo "-------------------"
 
-if ! $EXEC/list_files --sha1  | tee ../a.sha1; then
+if ! $EXEC/src/apps/file/list_files --sha1  | tee ../a.sha1; then
    echo ""
    echo "list_files --sha1 failed"
    echo ""
@@ -153,7 +153,7 @@ echo "---------------------"
 echo " sha256 checksums..."
 echo "---------------------"
 
-if ! $EXEC/list_files --sha256  | tee ../a.sha256; then
+if ! $EXEC/src/apps/file/list_files --sha256  | tee ../a.sha256; then
    echo ""
    echo "list_files --sha256 failed"
    echo ""
@@ -171,7 +171,7 @@ echo "---------------------"
 echo " sha512 checksums..."
 echo "---------------------"
 
-if ! $EXEC/list_files --sha512  | tee ../a.sha512; then
+if ! $EXEC/src/apps/file/list_files --sha512  | tee ../a.sha512; then
    echo ""
    echo "list_files --sha512 failed"
    echo ""
@@ -195,7 +195,7 @@ echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
 
-if $EXEC/verify_file --remove-no-shred *; then
+if $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred succeeded when one changed file was not removed"
    echo ""
@@ -209,7 +209,7 @@ ls
 echo "---------------------"
 echo " add-revision..."
 echo "---------------------"
-if ! $EXEC/import_file --add-revision computer.c; then
+if ! $EXEC/src/apps/file/import_file --add-revision computer.c; then
    echo ""
    echo "import_file --add-revision failed"
    echo ""
@@ -222,7 +222,7 @@ cp -piv computer.c ../computer.c.save
 echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
-if ! $EXEC/verify_file --remove-no-shred *; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred succeeded"
    echo ""
@@ -232,7 +232,7 @@ fi
 echo "---------------------"
 echo " export files..."
 echo "---------------------"
-if ! $EXEC/export_file computer.c; then
+if ! $EXEC/src/apps/file/export_file computer.c; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -245,9 +245,9 @@ rmdup ../computer.c.save computer.c
 echo "---------------------"
 echo " compress..."
 echo "---------------------"
-if ! $EXEC/compress_sparse ../compressed; then
+if ! $EXEC/src/apps/util/compress_archive ../compressed; then
    echo ""
-   echo "compress_sparse failed"
+   echo "compress_archive failed"
    echo ""
    exit 1
 fi
@@ -256,7 +256,7 @@ fi
 echo "--------------------------"
 echo " prep disk for restore..."
 echo "--------------------------"
-if ! $EXEC/prep_disk --no-private; then
+if ! $EXEC/src/apps/util/prep_disk --no-private; then
    echo ""
    echo "prep_disk --no-private failed"
    echo ""
@@ -267,16 +267,16 @@ fi
 echo "---------------------"
 echo " expand..."
 echo "---------------------"
-if ! $EXEC/expand_sparse ../compressed; then
+if ! $EXEC/src/apps/util/restore_archive ../compressed; then
    echo ""
-   echo "expand_sparse failed"
+   echo "restore_archive failed"
    echo ""
    exit 1
 fi
 
 
 
-if ! $EXEC/export_file "*"; then
+if ! $EXEC/src/apps/file/export_file "*"; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -290,7 +290,7 @@ echo "-------------------"
 echo " md5 checksums..."
 echo "-------------------"
 
-if ! $EXEC/list_files --md5  | tee ../a.md5; then
+if ! $EXEC/src/apps/file/list_files --md5  | tee ../a.md5; then
    echo ""
    echo "list_files --md5 failed"
    echo ""
@@ -309,7 +309,7 @@ echo "-------------------"
 echo " sha1 checksums..."
 echo "-------------------"
 
-if ! $EXEC/list_files --sha1  | tee ../a.sha1; then
+if ! $EXEC/src/apps/file/list_files --sha1  | tee ../a.sha1; then
    echo ""
    echo "list_files --sha1 failed"
    echo ""
@@ -328,7 +328,7 @@ echo "---------------------"
 echo " sha256 checksums..."
 echo "---------------------"
 
-if ! $EXEC/list_files --sha256  | tee ../a.sha256; then
+if ! $EXEC/src/apps/file/list_files --sha256  | tee ../a.sha256; then
    echo ""
    echo "list_files --sha256 failed"
    echo ""
@@ -346,7 +346,7 @@ echo "---------------------"
 echo " sha512 checksums..."
 echo "---------------------"
 
-if ! $EXEC/list_files --sha512  | tee ../a.sha512; then
+if ! $EXEC/src/apps/file/list_files --sha512  | tee ../a.sha512; then
    echo ""
    echo "list_files --sha512 failed"
    echo ""
@@ -364,7 +364,7 @@ fi
 echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
-if ! $EXEC/verify_file --remove-no-shred *; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred failed"
    echo ""
@@ -378,7 +378,7 @@ ls
 echo "---------------------------"
 echo " list revision and time..."
 echo "---------------------------"
-if ! $EXEC/list_files --time --revision; then
+if ! $EXEC/src/apps/file/list_files --time --revision; then
    echo ""
    echo "list_files --time --revision failed"
    echo ""
