@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
-#   $Revision: 4184 $
+#   $Date: 2009-08-15 07:29:25 -0600 (Sat, 15 Aug 2009) $
+#   $Revision: 4336 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -104,7 +104,7 @@ cat    x3670016    x3670016 >   x7340032
 echo "---------------"
 echo " prep disk..."
 echo "---------------"
-if ! $EXEC/prep_disk; then
+if ! $EXEC/src/apps/util/prep_disk; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -114,7 +114,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --extreme-security x14 x917504 x112; then
+if ! $EXEC/src/apps/file/import_file --extreme-security x14 x917504 x112; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -124,7 +124,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --minimal-security x7*; then
+if ! $EXEC/src/apps/file/import_file --minimal-security x7*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -134,7 +134,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --low-security x114688; then
+if ! $EXEC/src/apps/file/import_file --low-security x114688; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -144,7 +144,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --medium-security x4*; then
+if ! $EXEC/src/apps/file/import_file --medium-security x4*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -154,7 +154,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --very-low-security x3*; then
+if ! $EXEC/src/apps/file/import_file --very-low-security x3*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -164,7 +164,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --high-security x2*; then
+if ! $EXEC/src/apps/file/import_file --high-security x2*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -175,7 +175,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --extreme-security x1792 x14336; then
+if ! $EXEC/src/apps/file/import_file --extreme-security x1792 x14336; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -185,7 +185,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --low-security x5*; then
+if ! $EXEC/src/apps/file/import_file --low-security x5*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -195,7 +195,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --high-security x896; then
+if ! $EXEC/src/apps/file/import_file --high-security x896; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -206,7 +206,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file --minimal-security x1835008; then
+if ! $EXEC/src/apps/file/import_file --minimal-security x1835008; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -220,7 +220,7 @@ echo "-----------------"
 mkdir test
 cd test
 
-if ! $EXEC/export_file "*"; then
+if ! $EXEC/src/apps/file/export_file "*"; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -233,7 +233,7 @@ sleep 2
 echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
-if ! $EXEC/verify_file --remove-no-shred *; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred succeeded"
    echo ""
@@ -244,9 +244,9 @@ fi
 echo "---------------------"
 echo " compress..."
 echo "---------------------"
-if ! $EXEC/compress_sparse ../compressed; then
+if ! $EXEC/src/apps/util/compress_archive ../compressed; then
    echo ""
-   echo "compress_sparse failed"
+   echo "compress_archive failed"
    echo ""
    exit 1
 fi
@@ -255,7 +255,7 @@ fi
 echo "--------------------------"
 echo " prep disk for restore..."
 echo "--------------------------"
-if ! $EXEC/prep_disk --no-private; then
+if ! $EXEC/src/apps/util/prep_disk --no-private; then
    echo ""
    echo "prep_disk --no-private failed"
    echo ""
@@ -266,16 +266,16 @@ fi
 echo "---------------------"
 echo " expand..."
 echo "---------------------"
-if ! $EXEC/expand_sparse ../compressed; then
+if ! $EXEC/src/apps/util/restore_archive ../compressed; then
    echo ""
-   echo "expand_sparse failed"
+   echo "restore_archive failed"
    echo ""
    exit 1
 fi
 
 
 
-if ! $EXEC/export_file "*"; then
+if ! $EXEC/src/apps/file/export_file "*"; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -288,7 +288,7 @@ for file in ../*.[ch]; do diff -s $file .; done
 echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
-if ! $EXEC/verify_file --remove-no-shred *; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred failed"
    echo ""
