@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
-#   $Revision: 4184 $
+#   $Date: 2009-08-15 07:01:24 -0600 (Sat, 15 Aug 2009) $
+#   $Revision: 4335 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -108,7 +108,7 @@ cat   x58720256   x58720256 > x117440512
 echo "---------------"
 echo " prep disk..."
 echo "---------------"
-if ! $EXEC/prep_disk; then
+if ! $EXEC/src/apps/util/prep_disk; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -118,7 +118,7 @@ fi
 echo "---------------"
 echo " import_files..."
 echo "---------------"
-if ! $EXEC/import_file x*; then
+if ! $EXEC/src/apps/file/import_file x*; then
    echo ""
    echo "import_file failed"
    echo ""
@@ -133,7 +133,7 @@ echo "-----------------"
 mkdir test
 cd test
 
-if ! $EXEC/export_file "*"; then
+if ! $EXEC/src/apps/file/export_file "*"; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -146,7 +146,7 @@ sleep 2
 echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
-if ! $EXEC/verify_file --remove-no-shred *; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred succeeded"
    echo ""
@@ -157,9 +157,9 @@ fi
 echo "---------------------"
 echo " compress..."
 echo "---------------------"
-if ! $EXEC/compress_sparse ../compressed; then
+if ! $EXEC/src/apps/util/compress_archive ../compressed; then
    echo ""
-   echo "compress_sparse failed"
+   echo "compress_archive failed"
    echo ""
    exit 1
 fi
@@ -168,7 +168,7 @@ fi
 echo "--------------------------"
 echo " prep disk for restore..."
 echo "--------------------------"
-if ! $EXEC/prep_disk --no-private; then
+if ! $EXEC/src/apps/util/prep_disk --no-private; then
    echo ""
    echo "prep_disk --no-private failed"
    echo ""
@@ -179,16 +179,16 @@ fi
 echo "---------------------"
 echo " expand..."
 echo "---------------------"
-if ! $EXEC/expand_sparse ../compressed; then
+if ! $EXEC/src/apps/util/restore_archive ../compressed; then
    echo ""
-   echo "expand_sparse failed"
+   echo "restore_archive failed"
    echo ""
    exit 1
 fi
 
 
 
-if ! $EXEC/export_file "*"; then
+if ! $EXEC/src/apps/file/export_file "*"; then
    echo ""
    echo "export_file failed"
    echo ""
@@ -201,7 +201,7 @@ for file in ../*.[ch]; do diff -s $file .; done
 echo "---------------------"
 echo " verify and remove..."
 echo "---------------------"
-if ! $EXEC/verify_file --remove-no-shred *; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    echo ""
    echo "verify_file --remove-no-shred failed"
    echo ""
