@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
-#   $Revision: 4184 $
+#   $Date: 2009-08-15 07:29:25 -0600 (Sat, 15 Aug 2009) $
+#   $Revision: 4336 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -77,7 +77,7 @@ echo "------------------"
 
 echo $OBJECTIFY_PRIVATE_PATH
 
-if ! $EXEC/prep_disk; then
+if ! $EXEC/src/apps/util/prep_disk; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -96,14 +96,14 @@ for ((num=1; num<250; num++)) do
     echo "File: $num" >> dir-1/file-$num.txt
 done
 
-if ! $EXEC/import_file --very-low-security -r dir-1/; then
+if ! $EXEC/src/apps/file/import_file --very-low-security -r dir-1/; then
    echo ""
    echo "import_file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/verify_file --remove-no-shred -r dir-1/; then
+if ! $EXEC/src/apps/file/verify_file --remove-no-shred -r dir-1/; then
    echo ""
    echo "verify_file failed"
    echo ""
@@ -113,17 +113,17 @@ fi
 
 for ((num=0; num<200; num++)); do
     echo "**********************************"
-    file=`list_files | $EXEC/attic/random_line`
+    file=`list_files | $EXEC/src/attic/random_line`
     echo $file;
 
-    if ! $EXEC/compress_sparse compressed-$num; then
+    if ! $EXEC/src/apps/util/compress_archive compressed-$num; then
        echo ""
-       echo "compress_sparse failed"
+       echo "compress_archive failed"
        echo ""
        exit 1
     fi
 
-    if ! $EXEC/remove_file --all-traces $file; then
+    if ! $EXEC/src/apps/file/remove_file --all-traces $file; then
        echo ""
        echo "remove_file failed"
        echo ""
@@ -131,7 +131,7 @@ for ((num=0; num<200; num++)); do
     fi
 
     if export_file "*"; then
-       if ! $EXEC/verify_file --remove-no-shred -r dir-1/; then
+       if ! $EXEC/src/apps/file/verify_file --remove-no-shred -r dir-1/; then
           echo ""
           echo "verify_file failed"
           echo ""
